@@ -1,6 +1,7 @@
 package DBIx::Class::DeploymentHandler::VersionHandler::Monotonic;
-$DBIx::Class::DeploymentHandler::VersionHandler::Monotonic::VERSION = '0.002212';
+$DBIx::Class::DeploymentHandler::VersionHandler::Monotonic::VERSION = '0.002234';
 use Moose;
+use DBIx::Class::DeploymentHandler::Types;
 
 # ABSTRACT: Obvious version progressions
 
@@ -9,24 +10,29 @@ use Carp 'croak';
 with 'DBIx::Class::DeploymentHandler::HandlesVersioning';
 
 has schema_version => (
-  isa      => 'Int',
+  isa      => 'DBIx::Class::DeploymentHandler::VersionNonObj',
+  coerce   => 1,
   is       => 'ro',
   required => 1,
 );
 
-has database_version => (
+has initial_version => (
   isa      => 'Int',
   is       => 'ro',
   required => 1,
 );
 
 has to_version => (
-  isa        => 'Int',
+  isa        => 'DBIx::Class::DeploymentHandler::VersionNonObj',
+  coerce     => 1,
   is         => 'ro',
   lazy_build => 1,
 );
 
-sub _build_to_version { $_[0]->schema_version }
+sub _build_to_version {
+  my $version = $_[0]->schema_version;
+  ref($version) ? $version->numify : $version;
+}
 
 has _version => (
   is         => 'rw',
@@ -37,7 +43,18 @@ has _version => (
 sub _inc_version { $_[0]->_version($_[0]->_version + 1 ) }
 sub _dec_version { $_[0]->_version($_[0]->_version - 1 ) }
 
-sub _build__version { $_[0]->database_version }
+sub _build__version { $_[0]->initial_version }
+
+# provide backwards compatibility for initial_version/database_version
+around BUILDARGS => sub {
+    my $orig  = shift;
+    my $class = shift;
+
+    my $args = $class->$orig(@_);
+    $args->{initial_version} = $args->{database_version}
+      if exists $args->{database_version} && !exists $args->{initial_version};
+    return $args;
+};
 
 sub previous_version_set {
   my $self = shift;
@@ -55,7 +72,7 @@ sub previous_version_set {
 
 sub next_version_set {
   my $self = shift;
-  if ($self->to_version < $self->_version) {
+  if ($self->to_version < $self->initial_version) {
     croak "you are trying to upgrade and your current version is greater\n".
           "than the version you are trying to upgrade to.  Either downgrade\n".
           "or update your schema"
@@ -93,7 +110,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2024 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
